@@ -5,6 +5,7 @@ from typing import Optional
 import structlog
 from structlog import contextvars
 from structlog.typing import EventDict
+from structlog_sentry import SentryProcessor
 
 from payla_utils.logging.default_configuration import get_default_logging_conf
 
@@ -75,6 +76,7 @@ class LoggingConfigurator:
             structlog.processors.UnicodeDecoder(),
             structlog.processors.ExceptionPrettyPrinter(),
             structlog.stdlib.ExtraAdder(),
+            SentryProcessor(event_level=logging.ERROR),
             structlog.processors.EventRenamer(to="message"),
             structlog.stdlib.ProcessorFormatter.wrap_for_formatter,
         ]
@@ -86,6 +88,7 @@ class LoggingConfigurator:
         self,
         custom_processors=None,
         formatter='json_formatter',
+        formatter_std_lib='json_formatter',
         tracing_enabled=False,
         extra_loggers_names: Optional[list[str]] = None,
     ):
@@ -95,6 +98,7 @@ class LoggingConfigurator:
                 log_level=self.log_level,
                 own_apps=self.own_apps,
                 formatter=formatter,
+                formatter_std_lib=formatter_std_lib,
             )
             for extra_logger_name in extra_loggers_names or []:
                 logger_init_config['loggers'][extra_logger_name] = {
